#
# spec file for package perl-Test-File
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-File
Name:           perl-Test-File
Version:        1.994.0
Release:        1.2
# 1.994 -> normalize -> 1.994.0
%define cpan_version 1.994
License:        Artistic-2.0
Summary:        Test file attributes
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BR/BRIANDFOY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(Test::Builder) >= 1.001006
BuildRequires:  perl(Test::Builder::Tester) >= 1.04
BuildRequires:  perl(Test::More) >= 1
Provides:       perl(Test::File) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This modules provides a collection of test utilities for file attributes.

Some file attributes depend on the owner of the process testing the file in
the same way the file test operators do. For instance, root (or super-user
or Administrator) may always be able to read files no matter the
permissions.

Some attributes don't make sense outside of Unix, either, so some tests
automatically skip if they think they won't work on the platform. If you
have a way to make these functions work on Windows, for instance, please
send me a patch. :) If you want to pretend to be Windows on a non-Windows
machine (for instance, to test 'skip()'), you can set the
'PRETEND_TO_BE_WINDOWS' environment variable.

The optional NAME parameter for every function allows you to specify a name
for the test. If not supplied, a reasonable default will be generated.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CITATION.cff examples SECURITY.md
%license LICENSE

%changelog
* Sat Jan  4 2025 Tina Müller <timueller+perl@suse.de>
- updated to 1.994.0 (1.994)
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.994 2025-01-03T06:58:48Z
  * refresh distro and move to BRIANDFOY
* Tue Jan  3 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.993
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.993 2022-12-31T20:33:55Z
  * Try harder to check for symlinks on Windows by stealing some code
  from Win32:: (Jean-Damien Durand) GitHub #36
  1.992_01 2022-11-10T21:59:59Z
  * Try harder to test Windows symlinks, #36 from Jean-Damien Durand
* Wed Feb 16 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.992
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.992 2022-02-15T19:40:16Z
  * GitHub #29 - race condition in tests for mtime, from Slaven Rezić.
  Most people never experienced this timing issue, so if you have this
  already you don't need to update.
* Fri Jan 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.991
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.991 2022-01-21T01:37:36Z
  * Enforce text files in some functions, as warned in #18.
  * Change up some diag messages: 1) lowercase first letter 2) not ! at
  end, and 3) use "file" instead of "filename". If you were matching on
  those, you may need to update your patterns.
* Sat Mar  6 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.448
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.448 2021-03-05T15:01:18Z
  * Promote to a user release
  1.447_01 2021-03-02T16:11:23Z
  * Try handling all-numeric user and group names (but, also, wtf?)
  Github #26.
* Thu Feb 25 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.447
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.447 2021-02-24T21:32:41Z
  * Trying harder to get the tests to pass on Cygwin
* Mon Feb 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.446
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.446 2021-02-20T21:18:48Z
  * Better cygwin detection, from Achim Gratz
* Wed Feb 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.445
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.445 2021-02-16T08:57:34Z
  * Get the tests to pass under Cygwin (Github #17, from Slaven Rezić)
* Thu Jan  7 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.444
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.444 2021-01-06T03:40:19Z
  * Remove Travis, add GitHub actions
  * Add file_is_symlink_not_ok
  1.443_03 2020-06-15T13:13:42Z
  * Merge some test additions from Desmond Daignault (GitHub #20)
  1.443_02 2020-06-15T12:10:34Z
  * Deprecated directories in tests appropriate for only plain files.
  It's a diag() message now but will be a test failure later.
  1.443_01 2020-06-12T11:54:41Z
  * change the file_writeable_ok tests to file_writable_ok, which
  is the correct spelling. The old names work but now warn to use
  the new name.
  * Some updates to refresh the tests.
  * Start mirroring Test2::Tools::File so we support the same names.
  Thanks to Torbjørn Lindahl for spotting rough edges.
* Tue Apr 18 2017 coolo@suse.com
- updated to 1.443
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.443 2017-04-17T08:41:35Z
  * Found another relative path require issue thanks to Ryan Voots
  http://blogs.perl.org/users/ryan_voots/2017/04/trials-and-troubles-with-changing-inc.html
  * This is another attempt at avoiding failures from the v5.26
  removal of . from @INC.
* Fri Sep 23 2016 coolo@suse.com
- updated to 1.442
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.442 2016-09-22T15:35:50Z
  * Update to stable release. This fixes an upcoming Perl @INC
  issue that removes the current directory from the default list.
  This affects only the test files which use a private library.
  If you already have this installed you don't need to update.
  1.441_01 2016-09-19T21:44:45Z
  * Fix for missing . in @INC (Github #14 https://github.com/briandfoy/test-file/issues/14)
  This relates to CVE-2016-1238
* Tue Jul  7 2015 coolo@suse.com
- updated to 1.44
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.44 2015-07-06T00:29:56Z
  * Fix file_has_* tests to work on Windows (RJBS) GitHub #13
  1.43_02 2015-06-24T15:21:57Z
  * check file_mode_has tests for Windows
* Tue Jun 23 2015 coolo@suse.com
- updated to 1.43
  see /usr/share/doc/packages/perl-Test-File/Changes
  1.43 2015-06-22T21:44:37Z
  * Don't install README.pod
* Thu Jun 18 2015 coolo@suse.com
- updated to 1.42
  see /usr/share/doc/packages/perl-Test-File/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.41
  see /usr/share/doc/packages/perl-Test-File/Changes
* Tue Dec 28 2010 pascal.bleser@opensuse.org
- initial version (1.29)
